ArrayBuilder

Struct ArrayBuilder 

#[doc(hidden)]
pub struct ArrayBuilder<T, N: ArrayLength<T>> { /* private fields */ }
Creates an array one element at a time using a mutable iterator you can write to with ptr::write.

Increment the position while iterating to mark off created elements, which will be dropped if into_inner is not called.

Implementations

Source

impl<T, N: ArrayLength<T>> ArrayBuilder<T, N>

#[doc(hidden)]
pub unsafe fn new() -> ArrayBuilder<T, N>

#[doc(hidden)]
pub unsafe fn iter_position(&mut self) -> (IterMut<'_, T>, &mut usize)

Creates a mutable iterator for writing to the array using ptr::write.

Increment the position value given as a mutable reference as you iterate to mark how many elements have been created.

#[doc(hidden)]
pub unsafe fn into_inner(self) -> GenericArray<T, N>

When done writing (assuming all elements have been written to), get the inner array.